/*
 * JBoss, Home of Professional Open Source
 * Copyright 2013 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @authors tag. All rights reserved.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.arquillian.transaction.api.annotation;

/**
 * Available transaction modes used for controlling transaction behaviour per
 * test methods.
 *
 * @author <a href="mailto:bartosz.majsak@gmail.com">Bartosz Majsak</a>
 */
public enum TransactionMode
{
   /**
    * Rollback transaction after every test.
    */
   ROLLBACK,
   /**
    * Commit transaction after test execution. <br/>
    * <b>Default behavior.</b>
    */
   COMMIT,
   /**
    * Instructs extension to not use transactions for tests execution.
    */
   DISABLED,
   /**
    * Determined using externalized configuration. COMMIT by default.
    */
   DEFAULT;
}
